//
// BinaryFileIndex.cpp - types for binary index file layout
//

#include "StdHdr.h"

#include "BinaryFileIndex.h"

#include "vos\File.h"

/**************************************************************************

>	vos::Error BinaryIndexEntry::WriteEntry(vos::File* pFile, const char* szLeafname)

	Author:		Tim Browse
	Date:		2001/10/25
	Inputs:		pFile - the file object to write the index entry data to.
				szLeafname - the leafname to use for this entry.
	Returns:	Error

	Purpose:	Write this entry to the specified file object, using the
				specified leafname.

**************************************************************************/

vos::Error BinaryIndexEntry::WriteEntry(vos::File* pFile, const char* szLeafname)
{
	// Pad name length to 4-byte boundary
	int RawNameLength = strlen(szLeafname) + 1;
	m_NameLength = (RawNameLength + 3) & ~3;

	// Write initial fields
	pFile->Write(this, sizeof(*this));

	// Write DWORD aligned name data.

	// => Work how much padding we need
	int Padding = m_NameLength - RawNameLength;
	ASSERT(Padding >= 0);

	// Write the name (with 0-terminator), then optional padding
	pFile->Write(szLeafname, RawNameLength);
	
	while (Padding > 0)
	{
		pFile->Write_byte(0);
		Padding--;
	}

	return VNOERROR;
}

/**************************************************************************

>	const char* BinaryIndexEntry::GetName() const

	Author:		Tim Browse
	Date:		2001/10/25
	Returns:	Leafname of the entry.

	Purpose:	Given that this object has been loaded as part of a binary
				index, access the leafname string stored in the entry.

**************************************************************************/

const char* BinaryIndexEntry::GetName() const
{
	char *pName = ((char*) this) + sizeof(*this);

	return pName;
}


uint32 BinaryIndexEntry::GetFileSize() const
{
	return m_cbFileSize;
//	return 0;
}

vos::Time BinaryIndexEntry::GetTime() const
{
	return m_Time;
//	return 0;
}

void BinaryIndexEntry::SetFileSize(uint32 FileSize)
{
	m_cbFileSize = FileSize;
}

void BinaryIndexEntry::SetTime(vos::Time Time)
{
	m_Time = Time;
}
