//
// FastFindWindow.h - the class declaration for the main window object.
//

#include "vgui\Application.h"

#include "vgui\Dialog.h"
#include "vgui\EditBox.h"
#include "vgui\AutoPrefDropDownList.h"
#include "vgui\Button.h"
#include "vgui\Size.h"
#include "vgui\CheckBox.h"
#include "vgui\AutoPrefs.h"

#include "vos\Time.h"
#include "vos\DiskFile.h"

#include "VolumeIndexBuilder.h"

#include "SearchResultsList.h"

class FileIndexWriter;

/**************************************************************************

>	class FastFindWindow : public vgui::Dialog

	Author:		vGUI AppWizard

	Purpose:	Implement the main window object for this application.

				This dialog is the top level logic control for the app - it
				allows the user to build an index, and search the index
				for files.

				The class uses multiple inheritance - the IndexBuilderMonitor
				interface is used to allow the dialog to display the
				progress of the index building operation.

**************************************************************************/

class FastFindWindow : public vgui::Dialog,
					   public IndexBuilderMonitor
{
	public:
		DECLARE_VGUI_MESSAGE_MAP();

	public:
		// Ctor/dtor
		FastFindWindow(vgui::Application *pApp);
		~FastFindWindow();

		// Set up the dialog
		virtual void OnInitDialog();

		// Called when the Start/Stop button is pressed
		bool OnStartStopIndex();

		// Called when the user clicks the Find button.
		bool OnFind();

		// Called to allow the user to edit the program options.
		bool OnOptions();

		// IndexBuilderMonitor interface
		virtual void UpdateStatus(const vos::FileSpec& CurrentFolder);
		virtual void IndexComplete();

		// Handle shutdown
		virtual void OnCancel();

	private:
		// Handle a double click on the results list view
		bool OnSearchResultsDoubleClick(int iItem);

		// Stop/start the indexing process.
		void StartIndexing();
		void StopIndexing();

		// Closes down all objects used to build an index.
		void ShutdownIndexing();

		// Convert a timestamp into a human readable string
		void GetFriendlyTime(const vos::Time& TimeStamp,
							 vos::String* pFriendlyTime);

		// Functions to display the status of an existing index
		void UpdateIndexInfo();
		void UpdateIndexInfo(vgui::StringResourceID IndexStatus, 
							 const vos::Time& IndexTimeStamp);

		// Try to load the index from disk
		bool LoadIndex();
		
	private:
		//
		// The objects we use to build the index...
		//

		// The main volume enumerator/indexer
		VolumeIndexBuilder* m_pIndexBuilder;

		// The index writer used by the volume index builder
		FileIndexWriter* m_pIndexFile;
		
		// The raw disk file we store all the index data in.
		vos::DiskFile* m_pIndexDiskFile;

		//
		// The dialog controls...
		//
		vgui::EditBox		m_IndexStatus;
		vgui::Button		m_IndexButton;
		vgui::EditBox		m_Results;
		SearchResultsList	m_ResultsList;

//		vgui::EditBox		m_SearchField;
		vgui::AutoPrefDropDownList	m_SearchField;

		vgui::AutoPrefCheckBox m_UseRegExp;

		// Flag to indicate that indexing has finished, so the indexing
		// objects can be disposed of
		bool m_bShutdownPending;

		// The index file we use to search for files
		// (i.e. this is what we load the index file into)
		FileIndex* m_pIndex;
};

