//
// FileIndex.h
//

#ifndef inc_FileIndex_h
#define inc_FileIndex_h

#include "vos\Errors.h"
#include "vos\FileSpec.h"

#include "vgui\Window.h"

#include "BinaryFileIndex.h"

/**************************************************************************

>	class FileIndex

	Author:		Tim Browse

	Date:		28/04/2001

	Purpose:	Provide a simple interface to the binary index file, in
				terms of iteration and searching.

**************************************************************************/

class FileIndex
{
	public:
		FileIndex();
		~FileIndex();

		// Load the index data from the specified index file.
		vos::Error Load(const vos::FileSpec fsIndex);

		//
		// Searching
		//
		
		// Call Search() first...
		bool Search(const vos::String& strPattern, 
					bool bUseRegExp,
					bool bAutoWildcard,
					vgui::Window* pParentWindow);

		// ...then use these three functions to process the results.
		int GetNumberOfSearchResults() const;
		BinaryIndexEntry* GetSearchResult(int iSearchResult) const;
		uint32 GetSearchTotalFileSize() const;

		bool SearchResultIsFolder(int iSearchResult) const;
		vos::String GetFullPathname(int iSearchResult) const;
		vos::String GetLeafname(int iSearchResult) const;
		vos::String GetFolder(int iSearchResult) const;
		uint32 GetFileSize(int iSearchResult) const;
		vos::Time GetTimeStamp(int iSearchResult) const;

		uint64 GetTotalFileSize() const { return m_cbTotalFileSize; }
		uint32 GetNumberOfFiles() const { return m_cFiles; }
		uint32 GetNumberOfFolders() const { return m_cFolders; }

		// Write a text version of this index file
		void WriteTextIndex(const vos::FileSpec& FS);

		// Access to data for searching
		BinaryIndexEntry** GetEntries() const { return m_pEntries; }
		int GetNumberOfEntries() const { return m_pHeader->m_cEntries; }
		void ClearSearchResults();
		void AddSearchResult(BinaryIndexEntry* pResult);

	private:
		void CleanUp();
		vos::Error SetUpIndices(BinaryIndexEntry* pIndexData, int cbIndexSize);
		bool FindSubstring(const char *szString, const char* szSubString);
		vos::String GetFullPathname(BinaryIndexEntry *pEntry) const;
		void GetFolder(BinaryIndexEntry *pEntryToName,
					   vos::FileSpec* pfsFolder) const;

		vos::String MakeRegularExpression(const vos::String& Pattern);

	private:
		// The raw file data
		byte* m_pIndexData;
		BinaryIndexHeader* m_pHeader;
		uint32 m_cIndexDataSize;

		// The index entries (which point into the raw file data)
		BinaryIndexEntry** m_pEntries;

		// Summary of index entries
		uint m_cFiles;
		uint m_cFolders;
		uint64 m_cbTotalFileSize;

		// Search results (which point into the raw file data)
		BinaryIndexEntry** m_pSearchResults;
		int m_cSearchResults;

};

#endif // !inc_FileIndex_h

