//
// FileIndexBuilder.h -- class to build an index
//

#ifndef inc_FileIndexBuilder_h
#define inc_FileIndexBuilder_h

#include "vos\FileSpec.h"
#include "vos\FileMatches.h"

//
// Forward class declarations
//
class FileIndexWriter;


/**************************************************************************

>	class FileIndexBuilder

	Author:		Tim Browse

	Date:		22/04/2001

	Purpose:	Create an index of a folder of files and sub-folders.

				This class uses recursion to scan a folder tree - a
				new FileIndexBuilder object is created for each folder
				we scan.  (This is done to simplify the context information
				management).

				The currently active child index builder is held in
				m_pChild - which, of course, may be NULL.

**************************************************************************/

class FileIndexBuilder
{
	public:
		// Constructor
		FileIndexBuilder(FileIndexWriter* pIndex,
						 const vos::FileSpec& FolderToIndex,
						 FileIndexBuilder* pParent);

		// Destructor
		~FileIndexBuilder();

		// Build the whole index in one go
		vos::Error BuildIndex();

		// Add more files to the index.
		vos::Error BuildIndex(int cFilesToIndex,
							  bool* pbFinished = NULL);

		// Find out where we're up to in indexing
		void GetCurrentFolder(vos::FileSpec* pCurrentFolder);

	private:
		vos::Error BuildIndex(bool bFileLimit,
							  int* pcFilesToIndex,
							  bool* pbFinished);

	private:
		// Index we are building
		FileIndexWriter* m_pIndex;

		// Parent index builder
		FileIndexBuilder* m_pParent;

		// The (root) folder we are indexing
		vos::FileSpec m_Folder;

		// Current context
		vos::FileMatches* m_pFiles;

		// Active child folder context
		FileIndexBuilder* m_pChild;
};

#endif // !inc_FileIndexBuilder_h
