//
// FileIndexWriter.h - class to allow index generation
//

#ifndef inc_FileIndexWriter_h
#define inc_FileIndexWriter_h

#include "vos\FileSpec.h"

/**************************************************************************

>	class FileIndexWriter

	Author:		Tim Browse
	Date:		2001/10/25

	Purpose:	Interface class for writing an index file.

				See BinaryFileIndexWriter and TextFileIndexWriter for
				concrete class examples.

**************************************************************************/

class FileIndexWriter
{
	public:
		virtual ~FileIndexWriter() {}

	public:
		// Add a file or folder to the index.
		//
		// NB. Add files/folders in order - you must not add a file/folder
		//     if its parent folder has not already been added to the
		//     index.
		virtual void AddFile(const vos::FileSpec& FileName,
							 uint32 cbFileSize,
							 const vos::Time Timestamp) = 0;
		
		virtual void AddFolder(const vos::FileSpec& FolderName,
							   const vos::Time Timestamp) = 0;

		// Close the index file, after all files/folders have been added.
		virtual void Close() = 0;
};

#endif // !inc_FileIndexWriter_h

