//
// TextFileIndexWriter.h - class to allow index generation
//

#ifndef inc_TextFileIndexWriter_h
#define inc_TextFileIndexWriter_h

#include "vos\File.h"

#include "FileIndexWriter.h"

#define kIndexMarker_Good ("GOOD")
#define kIndexMarker_Bad  ("BAD!")

/**************************************************************************

>	class TextFileIndexWriter : public FileIndexWriter

	Author:		Tim Browse
	Date:		2001/10/25

	Purpose:	Simple index builder - simply a text file where each line
				names a file/folder object.  Used mainly for testing - now
				we use BinaryFileIndexWriter for everything, as it is
				faster and produces smaller index files.

				NB. The first line of a text index file contains the index
					status - "GOOD" or "BAD!" - see above.

**************************************************************************/

class TextFileIndexWriter : public FileIndexWriter
{
	public:
		// Constructor/destructor
		TextFileIndexWriter(vos::File* pIndexFile);
		~TextFileIndexWriter();

	public:
		// FileIndexWriter interface.
		virtual void AddFile(const vos::FileSpec& FileName,
							 uint32 cbFileSize,
							 const vos::Time Timestamp);

		virtual void AddFolder(const vos::FileSpec& FolderName,
							   const vos::Time Timestamp);

		virtual void Close();

	private:
		// The file we are writing the index data to.
		vos::File* m_pFile;
};

#endif // !inc_TextFileIndexWriter_h

