//
// VolumeIndexBuilder.h
//

#ifndef inc_VolumeIndexBuilder_h
#define inc_VolumeIndexBuilder_h

#include "vos\Errors.h"

#include "vgui\Application.h"

#include "FileIndex.h"

class FileIndexBuilder;
class FileIndexWriter;

/**************************************************************************

>	class IndexBuilderMonitor

	Author:		Tim Browse
	Date:		2001/10/25

	Purpose:	Interface class for an object that monitors the progress
				of building an index.  The VolumeIndexBuilder class will
				call this interface's functions at the appropriate times
				while the index is being built.

**************************************************************************/

class IndexBuilderMonitor
{
	public:
		// Provided the name of the folder currently being scanned
		virtual void UpdateStatus(const vos::FileSpec& CurrentFolder) = 0;

		// Called when the index has been built.
		virtual void IndexComplete() = 0;
};

/**************************************************************************

	class VolumeIndexBuilder : public vgui::IdleHandler

	Author:		Tim Browse

	Date:		2001/10/25

	Purpose:	Scans the host computer for all local fixed drives, 
				and builds an index that contains information about
				all these drives.

				The class uses vGUI idle events to do the indexing.

**************************************************************************/

class VolumeIndexBuilder : public vgui::IdleHandler
{
	public:
		// Ctor/dtor
		VolumeIndexBuilder(IndexBuilderMonitor* pMonitor = NULL);
		~VolumeIndexBuilder();

		// Direct index building
		vos::Error BuildIndexes(FileIndexWriter* pIndexFile);
		vos::Error BuildIndexes(FileIndexWriter* pIndexFile,
								int cFilesToIndex, 
								bool *pbFinished);

		// Background index building
		vos::Error StartIndexing(FileIndexWriter* pIndexFile);
		void StopIndexing();

		// Pause/restart background index building
		void PauseIndexing();
		void ContinueIndexing();

		// Current status
		bool IsIndexing(vos::FileSpec *pCurrentFolder = NULL);

		// Idle event handler
		virtual bool OnIdle(uint iIdleEvent);

	public:
		// The index file to store the index data in when doing background
		// index.
		FileIndexWriter* m_pBgIndexFile;

	private:
#ifdef VOS_MSWINDOWS
		// The list of logical drives on the system.
		char* m_pDrives;

		// Current drive we are scanning.
		char *m_pCurrentDrive;
		UINT m_DriveType;
#else
#error This class needs porting
#endif

		// Current index builder
		FileIndexBuilder* m_pIndexBuilder;

		// Used to indicate when we've finished building an index
		// in the background.
		bool m_bBgIndexFinished;

		// Used to update UI when doing background interface
		IndexBuilderMonitor* m_pBuildMonitor;
};

#endif // !inc_VolumeIndexBuilder_h
